@@ -1,17 +1,15 @@
 #!/usr/bin/perl
 
 #===============================================================================
-#     REVISION:  $Id: test1.pl 34 2011-02-20 14:07:25Z xdr.box $
+#     REVISION:  $Id: test1.pl 55 2011-02-25 21:41:33Z xdr.box $
 #  DESCRIPTION:  fix some with violations but introduce new
 #===============================================================================
 
 #use strict;
-use warnings;
+#use warnings;
 
 our $VERSION = '1.0';
 
-sub { print $_[0] }
-
 sub main {
     return;
 }
