@@ -1,17 +1,15 @@
 #!/usr/bin/perl
 
 #===============================================================================
-#     REVISION:  $Id: test1.pl 37 2011-02-20 15:02:11Z xdr.box $
+#     REVISION:  $Id: test1.pl 56 2011-02-25 21:48:58Z xdr.box $
 #  DESCRIPTION:  Some violations
 #===============================================================================
 
 #use strict;
-use warnings;
+#use warnings;
 
 our $VERSION = '1.0';
 
-sub { print $_[0] }
-
 sub main {
     return;
 }
